import test from 'ava'
import {decode} from '../../src/lib/parser'
import s12Mapping from './config/s12.json'
import s13Mapping from './config/s13.json'
import s14Mapping from './config/s14.json'
import s15Mapping from './config/s15.json'
import s17Mapping from './config/s17.json'
import s26Mapping from './config/s26.json'

test(`S12 - Notification of new appointment booking`, t => {
  const s12 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20160923155836||SIU^S12|154779|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s12, s12Mapping)
  t.is(obj.msh.message_datetime, '20160923155836')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S12')
  t.is(obj.msh.message_control_id, '154779')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})

test(`S13 - Notification of appointment rescheduling`, t => {
  const s13 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20160923155836||SIU^S13|154779|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s13, s13Mapping)
  t.is(obj.msh.message_datetime, '20160923155836')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S13')
  t.is(obj.msh.message_control_id, '154779')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})

test(`S14 - Notification of appointment modification`, t => {
  const s14 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20160923155836||SIU^S14|154779|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s14, s14Mapping)
  t.is(obj.msh.message_datetime, '20160923155836')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S14')
  t.is(obj.msh.message_control_id, '154779')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})

test(`S15 - Notification of appointment cancellation`, t => {
  const s15 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20161231110000||SIU^S15|256660|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s15, s15Mapping)
  t.is(obj.msh.message_datetime, '20161231110000')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S15')
  t.is(obj.msh.message_control_id, '256660')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})

test(`S17 - Notification of appointment deletion`, t => {
  const s17 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20161231110000||SIU^S17|256660|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s17, s17Mapping)
  t.is(obj.msh.message_datetime, '20161231110000')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S17')
  t.is(obj.msh.message_control_id, '256660')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})

test(`S26 - Notification that patient did not show up for scheduled appointment`, t => {
  const s26 = `MSH|^~\\&|mllp_http_proxy|proxy00-prodaz|mllp_http_proxypartenaire|proxy00-prodpartenaire|20161231110000||SIU^S26|256660|P|2.5.1|||||FRA|UTF-8|\rSCH||49849903800^DimSolution||||100|||||^^30^20161231110000|||||10101041431^KAYSSIEH^BASSEL||||ODS|||||Booked|\rPID|||123456^^^ODS^^PI||DO BAIRRO^Dimitri^^^^^L||19920506|M|Nom usuel||Avenue des Champs-Élysées^^Paris^^75000^^^^^||0100000000^^^dimitri.dobairro@dimsolution.com^^^^~0200000000^^^^^^^|\rRGS|1\rAIG|1|||10101041431@750057689\rNTE|||My comment`
  const obj = decode(s26, s26Mapping)
  t.is(obj.msh.message_datetime, '20161231110000')
  t.is(obj.msh.message_type, 'SIU')
  t.is(obj.msh.message_type_ref, 'S26')
  t.is(obj.msh.message_control_id, '256660')
  t.is(obj.msh.principal_language_of_message, 'FRA')
  t.is(obj.msh.character_set, 'UTF-8')
  t.is(obj.pid.id, '123456')
  t.is(obj.pid.origin, 'ODS')
  t.is(obj.pid.first_name, 'Dimitri')
  t.is(obj.pid.last_name, 'DO BAIRRO')
  t.is(obj.pid.birthdate, '19920506')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.gender, 'M')
  t.is(obj.pid.street_name, 'Avenue des Champs-Élysées')
  t.is(obj.pid.city, 'Paris')
  t.is(obj.pid.phone[0], '0100000000')
  t.is(obj.pid.phone[1], '0200000000')
  t.is(obj.pid.email[0], 'dimitri.dobairro@dimsolution.com')
  t.is(obj.pid.email[1], '')
  t.is(obj.sch.id, '49849903800')
  t.is(obj.sch.origin, 'DimSolution')
  t.is(obj.sch.length, '100')
  t.is(obj.sch.minutes, '30')
  t.is(obj.sch.datetime, '10101041431')
  t.is(obj.sch.last_name, 'KAYSSIEH')
  t.is(obj.sch.first_name, 'BASSEL')
  t.is(obj.sch.source, 'ODS')
  t.is(obj.sch.status, 'Booked')
  t.is(obj.rgs.id, '1')
  t.is(obj.aig.id, '1')
  t.is(obj.aig.rpps_finess, '10101041431@750057689')
  t.is(obj.nte.comment, 'My comment')
})
